/************************************************************************/
/* helpers.h								*/
/************************************************************************/
/*
 *  (c)2021 Todd Shadburn <tshadburn@opencomputingsolutions.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/************************************************************************/



#ifndef _HELPERS_H_
#define _HELPERS_H_


#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <netinet/in.h>
#include <signal.h>



#define CMD_PING			0x0001
#define CMD_ERROR			0x0002
#define CMD_PACKET_STATS		0x0010
#define	CMD_SET_LOG_LEVEL		0x0011
#define CMD_FILTER_ADD			0x0021
#define CMD_FILTER_REMOVE		0x0022
#define CMD_LIST_PFMS			0x0050
#define CMD_PFM_COMMAND			0x0051
#define CMD_RESPONSE			0x8000

#define VOTE_PASS			0
#define VOTE_DENY			1
#define VOTE_DROP			2
#define VOTE_LOG			3



void dump_memory_hex(char *p, int len);


uint32_t	ipv4_cidr_to_mask(uint8_t bits);
uint16_t	protocol_to_l4_type(char *name);


//static inline uint8_t buffer_peek_uint8 (uint8_t *buffer, int offset);
//static inline uint16_t buffer_peek_uint16 (uint8_t *buffer, int offset);
//static inline uint32_t buffer_peek_uint32 (uint8_t *buffer, int offset);


static inline uint8_t buffer_peek_uint8 (char *buffer, int offset) {
	return buffer[offset];
}


static inline uint16_t buffer_peek_uint16 (char *buffer, int offset) {
	uint16_t	v;
	v = (buffer[offset])<<8;
	v += buffer[offset+1];
	return v;
}


static inline uint32_t buffer_peek_uint32 (char *buffer, int offset) {
	uint32_t	v;
	v = (buffer[offset])<<24;
	v += (buffer[offset+1])<<16;
	v += (buffer[offset+2])<<8;
	v += buffer[offset+3];
	return v;
}


static inline int buffer_poke_uint8 (char *buffer, int offset, uint8_t value) {
	buffer[offset] = value;
	return 0;
}


static inline int buffer_poke_uint16 (char *buffer, int offset, uint16_t value) {
	buffer[offset] = (value>>8)&0xff;
	buffer[offset+1] = value&0xff;
	return 0;
}


static inline int buffer_poke_uint32 (char *buffer, int offset, uint32_t value) {
	buffer[offset] = (value>>24)&0xff;
	buffer[offset+1] = (value>>16)&0xff;
	buffer[offset+2] = (value>>8)&0xff;
	buffer[offset+3] = value&0xff;
	return 0;
}


#endif


