/************************************************************************/
/* helpers.c								*/
/************************************************************************/
/*
 *  (c)2021 Todd Shadburn <tshadburn@opencomputingsolutions.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/************************************************************************/


#include <stdint.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <stdarg.h>
#include <errno.h>
#include <netinet/in.h>
#include <netdb.h>
#include <time.h>
#include <fcntl.h>
#include <signal.h>

#include <helpers.h>


void dump_memory_hex(char *p, int len)
{
	int i;
	int w = 0;
	uint8_t	*up = (uint8_t*)p;
	printf ("\n");
	for (i=0 ; i<len ; i++) {
		if (up[i] >= 33 && up[i] <= 126)
			printf("%4c ", up[i]);
		else
			printf("0x%02x ", up[i]);
		w++;
		if (w == 16) {
			printf ("\n");
			w = 0;
		}
	}
	printf ("\n");
	return;
}


uint32_t	cidr_mask[] = {
	0x00000000,	// /0
	0x80000000,
	0xc0000000,
	0xe0000000,
	0xf0000000,	// /4
	0xf8000000,
	0xfc000000,
	0xfe000000,
	0xff000000,	// /8
	0xff800000,
	0xffc00000,
	0xffe00000,
	0xfff00000,	// /12
	0xfff80000,
	0xfffc0000,
	0xfffe0000,
	0xffff0000,	// /16
	0xffff8000,
	0xffffc000,
	0xffffe000,
	0xfffff000,	// /20
	0xfffff800,
	0xfffffc00,
	0xfffffe00,
	0xffffff00,	// /24
	0xffffff80,
	0xffffffc0,
	0xffffffe0,
	0xfffffff0,	// /28
	0xfffffff8,
	0xfffffffc,
	0xfffffffe,
	0xffffffff,	// /32
};


uint32_t        ipv4_cidr_to_mask(uint8_t bits)
{
	if (bits > 32)
		return 0x00000000;
	return cidr_mask[bits];
}


uint16_t        protocol_to_l4_type(char *name)
{
	if (!strcmp(name, "udp"))
		return 0x11;
	else if (!strcmp(name, "tcp"))
		return 0x06;
	return 0;

}

